#!perl -T
use open ':locale';
use strict;
use warnings;
print " noite, vov Kowalsky v o m cair no p do pingim queixoso e vov pe acar no ch de tmaras do jabuti feliz.\n";
